@@ -1,9 +1,6 @@
 package JIRA::REST;
-{
-  $JIRA::REST::VERSION = '0.010';
-}
 # ABSTRACT: Thin wrapper around JIRA's REST API
-
+$JIRA::REST::VERSION = '0.011';
 use 5.010;
 use utf8;
 use strict;
@@ -51,8 +48,22 @@ sub new {
     is_hash_ref($rest_client_config)
         or croak __PACKAGE__ . "::new: REST_CLIENT_CONFIG argument must be a hash-ref.\n";
 
+    # remove the REST::Client faux config value 'proxy' if set and use it
+    # ourselves.
+    my $proxy = delete $rest_client_config->{proxy};
+
+    if ($proxy) {
+        is_string($proxy) || is_instance($proxy, 'URI')
+            or croak __PACKAGE__ . "::new: 'proxy' rest client attribute must be a string or a URI object.\n";
+    }
+
     my $rest = REST::Client->new($rest_client_config);
 
+    # Set proxy to be used
+    if ($proxy) {
+        $rest->getUseragent->proxy(['http','https'] => $proxy);
+    }
+
     # Set default base URL
     $rest->setHost($URL);
 
@@ -115,7 +126,7 @@ sub _error {
         }
     } elsif ($type =~ m:text/html:i && eval {require HTML::TreeBuilder}) {
         $msg .= HTML::TreeBuilder->new_from_content($content)->as_text;
-    } elsif ($type =~ m:^text/:i) {
+    } elsif ($type =~ m:^(text/|application|xml):i) {
         $msg .= "<Content-Type: $type>$content</Content-Type>";
     } else {
         $msg .= "<Content-Type: $type>(binary content not shown)</Content-Type>";
@@ -285,7 +296,7 @@ JIRA::REST - Thin wrapper around JIRA's REST API
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -384,6 +395,11 @@ invocations. This optional argument must be a hash-ref that can be fed
 to the REST::Client constructor. Note that the C<URL> argument
 overwrites any value associated with the C<host> key in this hash.
 
+To use a network proxy please set the 'proxy' argument to the string or URI
+object describing the fully qualified (including port) URL to your network
+proxy. This is an extension to the REST::Client configuration and will be
+removed from the hash before passing it on to the REST::Client constructor.
+
 =back
 
 =head1 REST METHODS
@@ -560,7 +576,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD <www.cpqd.com.br>.
+This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
